/*
 * This software is governed by the CeCILL-B license under French law and
 * abiding by the rules of distribution of free software. You can use, modify
 * and/ or redistribute the software under the terms of the CeCILL-B license as
 * circulated by CEA, CNRS and INRIA at the following URL "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and rights to copy, modify
 * and redistribute granted by the license, users are provided only with a
 * limited warranty and the software's author, the holder of the economic
 * rights, and the successive licensors have only limited liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated with
 * loading, using, modifying and/or developing or reproducing the software by
 * the user in light of its specific status of free software, that may mean that
 * it is complicated to manipulate, and that also therefore means that it is
 * reserved for developers and experienced professionals having in-depth
 * computer knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions enabling
 * the security of their systems and/or data to be ensured and, more generally,
 * to use and operate it in the same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-B license and that you accept its terms.
 */
package fr.amap.lidar.amapvox.visualization.controllers.inputs;

import java.util.LinkedHashMap;
import java.util.Map;

/**
 * Static class to collect all 3D inputs events.
 * @author Tristan Muller (tristan.muller@cirad.fr)
 */
public class Input {
    
    /**
     * List of all buttons states.
     * Used to know if a button is pressed or released.
     */
    private static final Map<Integer, ButtonStateType> BUTTONS 
            = new LinkedHashMap();
    
    /**
     * The mouse attached with the 3D view.
     * Used to get the location of the cursor.
     */
    private static Mouse mouse = new Mouse(0, 0, 0);
    
    /**
     * Specify if the mouse has been scrolled during the last processing.
     */
    private static boolean scrolled = false;
    
    /**
     * Add a button state to the states list.
     * Used when a button is pressed or released.
     * @param button The button id.
     * @param state The state of the button.
     */
    public static final void setButton(final int button, 
            final ButtonStateType state) {
        if (BUTTONS.containsKey(button)) {
            BUTTONS.replace(button, state);
        } else {
            BUTTONS.put(button, state);
        }
    }
    
    public static void setScrolled(final boolean scrolled) {
        Input.scrolled = scrolled;
    }
    
    /**
     * Set the current mouse cursor location.
     * @param mouse New mouse object
     */
    public static final void setMouse(final Mouse mouse) {
        Input.mouse = mouse;
    }
    
    /**
     * Check if a button is pressed or not.
     * @param button The button id to check.
     * @return True when press or False.
     */
    public static final boolean getButtonPress(final int button) {
        if (BUTTONS.containsKey(button)) {
            if (BUTTONS.get(button) == ButtonStateType.PRESSED) {
                return true;
            }
        }
        
        return false;
    }
    
    /**
     * Check if a button is released or not.
     * @param button The button id to check.
     * @return True when release or False.
     */
    public static final boolean getButtonRelease(final int button) {
        if (BUTTONS.containsKey(button)) {
            if (BUTTONS.get(button) == ButtonStateType.RELEASED) {
                return true;
            }
        }
        
        return false;
    }
    
    /**
     * Get the current mouse cursor position.
     * @return Mouse object.
     */
    public static final Mouse getMouse() {
        return mouse;
    }

    /**
     * Get if the mouse has been scrolled.
     * @return 
     */
    public static boolean isScrolled() {
        boolean s = scrolled;
        scrolled = false;
        return s;
    }
    
}
