/*
 * This software is governed by the CeCILL-B license under French law and
 * abiding by the rules of distribution of free software. You can use, modify
 * and/ or redistribute the software under the terms of the CeCILL-B license as
 * circulated by CEA, CNRS and INRIA at the following URL "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and rights to copy, modify
 * and redistribute granted by the license, users are provided only with a
 * limited warranty and the software's author, the holder of the economic
 * rights, and the successive licensors have only limited liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated with
 * loading, using, modifying and/or developing or reproducing the software by
 * the user in light of its specific status of free software, that may mean that
 * it is complicated to manipulate, and that also therefore means that it is
 * reserved for developers and experienced professionals having in-depth
 * computer knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions enabling
 * the security of their systems and/or data to be ensured and, more generally,
 * to use and operate it in the same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-B license and that you accept its terms.
 */
package fr.amap.lidar.amapvox.visualization.controllers.loadables.meshes.base;

import org.joml.Vector2f;
import org.joml.Vector3f;

/**
 * Used to store the indices of a mesh (primitive).
 * @author Tristan Muller (tristan.muller@cirad.fr)
 */
public abstract class Face {
    
    /**
     * Indices array.
     */
    private final int[] indices;
    private final Vector3f normal;
    private final Vector2f texcoord;

    /**
     * Create a Face by specifying its indices array.
     * @param indices 
     */
    public Face(final int... indices) {
        this.indices = indices;
        this.normal = new Vector3f();
        this.texcoord = new Vector2f();
    }
    
    /**
     * Create a Face by specifying its indices array and normal.
     * @param normal
     * @param indices 
     */
    public Face(final Vector3f normal, final int... indices) {
        this.indices = indices;
        this.normal = normal;
        this.texcoord = new Vector2f();
    }
    
    /**
     * Create a Face by specifying its indices array and normal.
     * @param normal
     * @param texcoord
     * @param indices 
     */
    public Face(final Vector3f normal, final Vector2f texcoord, final int... indices) {
        this.indices = indices;
        this.normal = normal;
        this.texcoord = texcoord;
    }

    /**
     * Get the indices array.
     * @return 
     */
    public final int[] getIndices() {
        return indices;
    }

    /**
     * Get the normal vector.
     * @return 
     */
    public final Vector3f getNormal() {
        return normal;
    }

    /**
     * Get the texcoord vector.
     * @return 
     */
    public final Vector2f getTexcoord() {
        return texcoord;
    }
    
}
