/*
 * This software is governed by the CeCILL-B license under French law and
 * abiding by the rules of distribution of free software. You can use, modify
 * and/ or redistribute the software under the terms of the CeCILL-B license as
 * circulated by CEA, CNRS and INRIA at the following URL "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and rights to copy, modify
 * and redistribute granted by the license, users are provided only with a
 * limited warranty and the software's author, the holder of the economic
 * rights, and the successive licensors have only limited liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated with
 * loading, using, modifying and/or developing or reproducing the software by
 * the user in light of its specific status of free software, that may mean that
 * it is complicated to manipulate, and that also therefore means that it is
 * reserved for developers and experienced professionals having in-depth
 * computer knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions enabling
 * the security of their systems and/or data to be ensured and, more generally,
 * to use and operate it in the same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-B license and that you accept its terms.
 */
package fr.amap.lidar.amapvox.visualization.controllers.loadables.meshes.base;

import org.joml.Vector3f;

/**
 * Simple class to create vertex objects.
 * @author Tristan Muller (tristan.muller@cirad.fr)
 */
public final class Vertex {
    
    /**
     * Vertex tridimensionnal position vertor.
     */
    private final Vector3f position;

    /**
     * Create a vertex placed at the origin (0, 0, 0).
     */
    public Vertex() {
        this.position = new Vector3f();
    }
    
    /**
     * Create a vertex at the specified position.
     * @param position 
     */
    public Vertex(final Vector3f position) {
        this.position = position;
    }
    
    /**
     * Create a vertex at the specified position.
     * @param xPosition
     * @param yPosition
     * @param zPosition 
     */
    public Vertex(final float xPosition, final float yPosition, final float zPosition) {
        this.position = new Vector3f(xPosition, yPosition, zPosition);
    }

    /**
     * Get the vertex tridimensionnal position vector.
     * @return 
     */
    public final Vector3f getPosition() {
        return position;
    }
    
}
