/*
 * This software is governed by the CeCILL-B license under French law and
 * abiding by the rules of distribution of free software. You can use, modify
 * and/ or redistribute the software under the terms of the CeCILL-B license as
 * circulated by CEA, CNRS and INRIA at the following URL "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and rights to copy, modify
 * and redistribute granted by the license, users are provided only with a
 * limited warranty and the software's author, the holder of the economic
 * rights, and the successive licensors have only limited liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated with
 * loading, using, modifying and/or developing or reproducing the software by
 * the user in light of its specific status of free software, that may mean that
 * it is complicated to manipulate, and that also therefore means that it is
 * reserved for developers and experienced professionals having in-depth
 * computer knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions enabling
 * the security of their systems and/or data to be ensured and, more generally,
 * to use and operate it in the same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-B license and that you accept its terms.
 */
package fr.amap.lidar.amapvox.visualization.controllers.loadables.meshes.lists;

import fr.amap.lidar.amapvox.visualization.controllers.loadables.meshes.base.Face;
import org.joml.Vector3f;

/**
 * Quad (square) face class.
 * @author Tristan Muller (tristan.muller@cirad.fr)
 */
public class QuadFace extends Face {

    /**
     * Create a quad face with the four vertex ids.
     * @param x
     * @param y
     * @param z
     * @param w 
     */
    public QuadFace(final int x, final int y, final int z, final int w) {
        super(x, y, z, w);
    }
    
    /**
     * Create a quad face with the four vertex ids and the normal coordinates.
     * @param x
     * @param y
     * @param z
     * @param w
     * @param xNormal
     * @param yNormal
     * @param zNormal 
     */
    public QuadFace(final int x, final int y, final int z, final int w,
            final float xNormal, final float yNormal, final float zNormal) {
        super(new Vector3f(xNormal, yNormal, zNormal), x, y, z, w);
    }
    
}
