/*
 * This software is governed by the CeCILL-B license under French law and
 * abiding by the rules of distribution of free software. You can use, modify
 * and/ or redistribute the software under the terms of the CeCILL-B license as
 * circulated by CEA, CNRS and INRIA at the following URL "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and rights to copy, modify
 * and redistribute granted by the license, users are provided only with a
 * limited warranty and the software's author, the holder of the economic
 * rights, and the successive licensors have only limited liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated with
 * loading, using, modifying and/or developing or reproducing the software by
 * the user in light of its specific status of free software, that may mean that
 * it is complicated to manipulate, and that also therefore means that it is
 * reserved for developers and experienced professionals having in-depth
 * computer knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions enabling
 * the security of their systems and/or data to be ensured and, more generally,
 * to use and operate it in the same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-B license and that you accept its terms.
 */
package fr.amap.lidar.amapvox.visualization.controllers.loadables.meshes.lists;

import fr.amap.lidar.amapvox.visualization.controllers.loadables.meshes.base.Vertex;
import java.util.Vector;
import org.joml.Vector3f;

/**
 * Commodity class to store vertices.
 * @author Tristan Muller (tristan.muller@cirad.fr)
 */
public final class VertexList {
    
    /**
     * The vertex list.
     */
    private final Vector<Vertex> vertices;
    
    /**
     * The vertex position array.
     */
    private float[] positions;

    /**
     * Create an empty vertex list.
     */
    public VertexList() {
        this.vertices = new Vector();
        this.positions = null;
    }
    
    /**
     * Add a vertex to the list.
     * @param vertex 
     */
    public final void addVertex(final Vertex vertex) {
        vertices.add(vertex);
    }
    
    /**
     * Get if the vertex list is empty.
     * @return 
     */
    public final boolean isEmpty() {
        return vertices.isEmpty();
    }
    
    /**
     * Get the vertex amount.
     * @return 
     */
    public final int getLength() {
        return vertices.size();
    }
    
    /**
     * Get the vertices positions array.
     * @return 
     */
    public final float[] getPositions() {
        if (positions == null) {
            positions = new float[vertices.size() * 3];
            
            int index = 0;
            
            for (Vertex vertex : vertices) {
                final Vector3f position = vertex.getPosition();
                positions[index] = position.x;
                index++;
                positions[index] = position.y;
                index++;
                positions[index] = position.z;
                index++;
            }
        }
        
        return positions;
    }
    
}
