/*
 * This software is governed by the CeCILL-B license under French law and
 * abiding by the rules of distribution of free software. You can use, modify
 * and/ or redistribute the software under the terms of the CeCILL-B license as
 * circulated by CEA, CNRS and INRIA at the following URL "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and rights to copy, modify
 * and redistribute granted by the license, users are provided only with a
 * limited warranty and the software's author, the holder of the economic
 * rights, and the successive licensors have only limited liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated with
 * loading, using, modifying and/or developing or reproducing the software by
 * the user in light of its specific status of free software, that may mean that
 * it is complicated to manipulate, and that also therefore means that it is
 * reserved for developers and experienced professionals having in-depth
 * computer knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions enabling
 * the security of their systems and/or data to be ensured and, more generally,
 * to use and operate it in the same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-B license and that you accept its terms.
 */
package fr.amap.lidar.amapvox.visualization.views;

import fr.amap.commons.util.swing.jprogress.JProgressEvent;
import fr.amap.commons.util.swing.jprogress.JProgressFrame;
import fr.amap.lidar.amapvox.visualization.controllers.voxels.Skyboxes;
import fr.amap.lidar.amapvox.visualization.controllers.voxels.VoxelSpaceFile;
import fr.amap.lidar.amapvox.visualization.controllers.voxels.Space;
import fr.amap.lidar.amapvox.visualization.controllers.voxels.ViewType;
import java.awt.BorderLayout;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import javax.swing.JFileChooser;
import javax.swing.JOptionPane;
import javax.swing.filechooser.FileNameExtensionFilter;

/**
 *
 * @author Tristan Muller (tristan.muller@cirad.fr)
 */
public class VisualizationFrame extends javax.swing.JFrame {

    /** Creates new form MainFrame */
    public VisualizationFrame() {
        initComponents();
        initChildren();
        setLocationRelativeTo(getParent());
    }

    public final void openFile() {
        final JFileChooser chooser = new JFileChooser();
        chooser.setFileFilter(new FileNameExtensionFilter("Voxel space files (.vox)", "vox"));
        chooser.setAcceptAllFileFilterUsed(false);

        int returnValue = chooser.showOpenDialog(this);

        if (returnValue == JFileChooser.APPROVE_OPTION) {
            try {
                final File selectedFile = chooser.getSelectedFile();
                final InputStream in = new FileInputStream(selectedFile);

                setFile(in, null);
            } catch(Exception ex) {
                JOptionPane.showMessageDialog(this,
                    "The selected file cannot be opened",
                    "Error", JOptionPane.ERROR_MESSAGE);
            }
        }
    }
    
    public final void setFile(final InputStream in, final String defaultProperty) {
        /* Create a progress bar and add a 
        listener for the parsing progression */
        final JProgressFrame progressFrame = new JProgressFrame(this);
        
        try {
            /* Check if an input file has been passed */
            if (in != null) {
                final VoxelSpaceFile file = new VoxelSpaceFile();

                progressFrame.setVisible(true);

                /* Generate the skies */
                progressFrame.setProgression(1, 4, "Generate skies...");
                Skyboxes.initializeSkies();

                /* Parse the file and check if it has been parsed */
                progressFrame.setProgression(2, 4, "Parse the voxel space file...");
                file.parse(in);

                /* Create the Voxel Space */
                progressFrame.setProgression(3, 4, "Generate 3D Voxel Space...");
                getView3DInternalFrame().getPanelVisualization()
                        .setSpace(new Space(file));

                /* Set the property names */
                progressFrame.setProgression(4, 4, "Set properties...");
                getPropertiesInternalFrame().setPropertyNames(file.getNames());

                /* Set the default property to the specified one */
                if (defaultProperty != null) {
                    getView3DInternalFrame().getPanelVisualization()
                            .getSpace().setProperty(defaultProperty);

                    getPropertiesInternalFrame().selectProperty(defaultProperty);
                }

                /* Close the progression frame and show the main frame */
                progressFrame.dispose();
                setVisible(true);

                getView3DInternalFrame().getPanelVisualization()
                        .getSpace().setView(ViewType.Z_NEG);
            } else {
                /* Or open a file chooser */
                openFile();
            }
        } catch (Exception ex) {
            ex.printStackTrace();
            JOptionPane.showMessageDialog(this,
                    "Something wrong happened : " + ex.getMessage(),
                    "Error", JOptionPane.ERROR_MESSAGE);
            progressFrame.dispose();
            setVisible(false);
        }
    }

    @Override
    public void dispose() {
        super.dispose();
        view3DInternalFrame.getPanelVisualization().getGLCanvas().destroy();
    }

    /** This method is called from within the constructor to initialize the
     * form. WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jToolBar1 = new javax.swing.JToolBar();
        jButtonOpen = new javax.swing.JButton();

        setTitle("AMAPVox - Visualization");
        setIconImage(new javax.swing.ImageIcon(getClass().
            getResource("/icons/visualization.png")).getImage());
    setMinimumSize(new java.awt.Dimension(640, 480));
    setPreferredSize(new java.awt.Dimension(900, 600));

    jToolBar1.setFloatable(false);

    jButtonOpen.setIcon(new javax.swing.ImageIcon(getClass().getResource("/icons/document-open.png"))); // NOI18N
    jButtonOpen.setText("Open");
    jButtonOpen.setToolTipText("Open another Voxel Space File");
    jButtonOpen.setCursor(new java.awt.Cursor(java.awt.Cursor.HAND_CURSOR));
    jButtonOpen.setFocusable(false);
    jButtonOpen.setHorizontalTextPosition(javax.swing.SwingConstants.RIGHT);
    jButtonOpen.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
    jButtonOpen.addActionListener(new java.awt.event.ActionListener() {
        public void actionPerformed(java.awt.event.ActionEvent evt) {
            jButtonOpenActionPerformed(evt);
        }
    });
    jToolBar1.add(jButtonOpen);

    getContentPane().add(jToolBar1, java.awt.BorderLayout.PAGE_START);

    pack();
    }// </editor-fold>//GEN-END:initComponents

    private void jButtonOpenActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButtonOpenActionPerformed
        openFile();
    }//GEN-LAST:event_jButtonOpenActionPerformed

    /**
     * This method is called after the components initialization to add their
     * children.
     */
    private void initChildren() {
        propertiesInternalFrame = new PropertiesInternalFrame(this);
        add(propertiesInternalFrame, BorderLayout.WEST);

        view3DInternalFrame = new View3DInternalFrame();
        add(view3DInternalFrame, BorderLayout.CENTER);
    }

    /**
     * Get the view 3D internal frame.
     * @return
     */
    public final View3DInternalFrame getView3DInternalFrame() {
        return view3DInternalFrame;
    }

    /**
     * Get the current properties internal frame.
     * @return
     */
    public final PropertiesInternalFrame getPropertiesInternalFrame() {
        return propertiesInternalFrame;
    }

    /**
     * Get the current 3D voxel space object.
     * @return
     */
    public final Space getSpace() {
        return view3DInternalFrame.getPanelVisualization().getSpace();
    }

    // Children declaration
    private PropertiesInternalFrame propertiesInternalFrame;
    private View3DInternalFrame view3DInternalFrame;
    // End of children declaration

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton jButtonOpen;
    private javax.swing.JToolBar jToolBar1;
    // End of variables declaration//GEN-END:variables
}
